import pandas as pd

# Flag to indicate whether to use the divided file or the undivided one
use_divided_file = False

if use_divided_file:
    file_path = 'filtered_file.xlsx'  # Path to the divided file
else:
    file_path = 'pigu.xlsx'  # Path to the undivided file

# Load the Excel file
df = pd.read_excel(file_path)

# Remove the second row
df = df.drop(1).reset_index(drop=True)

# Filter rows where 'country' is either 'lt', 'lv', 'ee', or 'fi'
filtered_df = df[df['country'].isin(['lt', 'lv', 'ee', 'fi'])].copy()

# If you want to skip the division process, uncomment the line below
#filtered_df = df

def apply_excel_formula(cell_value):
    if pd.isna(cell_value):
        return 'BRAK'
    elif len(cell_value) <= 7 and '_' not in cell_value:
        return 'Vida'
    elif cell_value[:3].isupper() and '_' not in cell_value:
        return 'Topsecret'
    else:
        try:
            return cell_value.split('_')[0]
        except AttributeError:
            return 'Kinghoff'


# Apply the formula to the 'supplierCode' column and create a new column
filtered_df['hurtownia'] = filtered_df['supplierCode'].apply(apply_excel_formula)

# List of columns to keep, including 'country' for grouping
columns_to_keep = [
    'supplierCode',
    'descriptionCheckedLt',
    'descriptionCheckedLv',
    'descriptionCheckedEe',
    'descriptionCheckedFi',
    'productStatus',
    'status',
    'amount',
    'hasInvalidPrice',
    'hasInsultPrice',
    'sellPrice',
    'buyboxPrice',
    'hurtownia',
    'country'
]

# Filter the dataframe to keep only the specified columns
filtered_df = filtered_df[columns_to_keep]

# Check if filtered_df is not empty before writing to Excel
if not filtered_df.empty:
    # Create a new Excel writer object
    with pd.ExcelWriter('pigu_buybox.xlsx', engine='openpyxl') as writer:
        for country, data in filtered_df.groupby('country'):
            # Write each dataframe to a different sheet
            data.to_excel(writer, sheet_name=country, index=False)
else:
    print("No data to write to Excel.")